==========
Helion SDK
==========

This repository contains the Helion SDK that is just a proof on concept
on creating a real OpenStack SDK plugin.

To try out the Helion SDK, install the package and run the following:

    helionsdk

The script loads the Helion plugin and calls the two methods of the
proxy.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/helionsdk
* Source: http://git.openstack.org/cgit/openstack/helionsdk
* Bugs: http://bugs.launchpad.net/helionsdk

TODO
----

* Write docs describing how to use it
* Fix this README with proper links to source and documentation
